@@ -3,6 +3,8 @@ from .hmac import validate
 from .httpclient import HTTPClient
 from .jwtoken import JWTBaseModel
 from .misc import get_unique_id, now_epoch
+from .rest import DELETE, GET, POST, PUT, Method
+from .session_token import SessionToken
 
 __all__ = [
     'now_epoch',
@@ -12,4 +14,10 @@ __all__ = [
     'HTTPClient',
     'domain_to_storename',
     'store_domain',
+    'Method',
+    'GET',
+    'POST',
+    'PUT',
+    'DELETE',
+    'SessionToken',
 ]
